==> vmaid-1.8.5.tar.gz: vmaid-1.8.5/dllloader/version.c <==
/*
    dllloader
    copyright (c) 2002 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/
#include "gdi32.h"
#include "module.h"
#include "windef.h"


/******************************************************************************
*                                                                             *
* Version                                                                     *
*                                                                             *
******************************************************************************/
static DWORD WINAPI GetFileVersionInfoSizeA(LPSTR lptstrFilename,
															LPDWORD lpdwHandle)
{
	return 0;
}


static BOOL WINAPI VerQueryValueA(LPCVOID pBlock,LPSTR lpSubBlock,
											LPVOID *lplpBuffer,UINT_PTR puLen)
{
	return FALSE;
}


static BOOL WINAPI GetFileVersionInfoA(LPSTR lptstrFilename,DWORD dwHandle,
													DWORD dwLen,LPVOID lpData)
{
	return FALSE;
}


/******************************************************************************
*                                                                             *
* Ͽ                                                                        *
*                                                                             *
******************************************************************************/
static VOID WINAPI UnknownSymbol(VOID)
{
	g_message("unknown symbol in version called\n");
}


static SymbolInfo symbol_infos[]={
	{"GetFileVersionInfoSizeA",GetFileVersionInfoSizeA},
	{"VerQueryValueA",VerQueryValueA},
	{"GetFileVersionInfoA",GetFileVersionInfoA},
	{NULL,UnknownSymbol}
};


SymbolInfo *version_get_export_symbols(void)
{
	module_register("gdl32.dll",symbol_infos);
	return symbol_infos;
}

==> vmaid-1.8.20.tar.gz: vmaid-1.8.20/dllloader/version.c <==
/*
    dllloader
    copyright (c) 2002 Kazuki IWAMOTO http://www.maid.org/ iwm@maid.org

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
*/
#include "version.h"


/******************************************************************************
*                                                                             *
* Version                                                                     *
*                                                                             *
******************************************************************************/
static BOOL WINAPI GetFileVersionInfoA(LPSTR lptstrFilename,DWORD dwHandle,
													DWORD dwLen,LPVOID lpData)
{
	g_debug("GetFileVersionInfoA");
	return FALSE;
}


static DWORD WINAPI GetFileVersionInfoSizeA(LPSTR lptstrFilename,
															LPDWORD lpdwHandle)
{
	g_debug("GetFileVersionInfoSizeA");
	if (lpdwHandle!=NULL)
		*lpdwHandle=0;
	return 0;
}


static BOOL WINAPI VerQueryValueA(LPCVOID pBlock,LPSTR lpSubBlock,
											LPVOID *lplpBuffer,UINT_PTR puLen)
{
	g_debug("VerQueryValueA");
	return FALSE;
}


/******************************************************************************
*                                                                             *
* Ͽ                                                                        *
*                                                                             *
******************************************************************************/
static VOID WINAPI UnknownSymbol(VOID)
{
	g_message("unknown symbol in version called");
}


static SymbolInfo symbol_infos[]={
	{"GetFileVersionInfoA",GetFileVersionInfoA},
	{"GetFileVersionInfoSizeA",GetFileVersionInfoSizeA},
	{"VerQueryValueA",VerQueryValueA},
	{NULL,UnknownSymbol}
};


SymbolInfo *version_get_export_symbols(void)
{
	return symbol_infos;
}
